error_path_impl

Attribute Macro error_path_impl 

#[error_path_impl]
Attach error paths to every Result-returning method in an impl block.

  • #[error_path_impl] uses the trait name for trait impls, otherwise the type name.
  • #[error_path_impl("custom.prefix")] uses the provided prefix.
  • #[error_path_skip] can be placed on methods that should not be wrapped.